@@ -39,10 +39,20 @@ __END__
 
 B::Hooks::EndOfScope::PP::HintHash
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Florian Ragwitz <rafl@debian.org>
 
+=item *
+
+Peter Rabbitson <ribasushi@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by Florian Ragwitz.
